/**
 * EIO Session: Solar System Example
 *
 * (C) 2007, Konstantin Tretyakov
 */

#include <GL/glut.h>

// ----------------------------------------------- //

/**
 * This function is invoked every time the screen is being repainted.
 */
void display() {
    // Clear screen
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    
    // Start with a clear modelview matrix
    glLoadIdentity();
    
    // We are using perspective projection now, so we have to set up
    // the viewer position. We'll be looking from point (0, 200, 1000)
    // onto point (0, 0, 0) with our "top" pointing towards (0, 1, 0);
    gluLookAt(0, 200, 500, 0, 0, 0, 0, 1, 0);
    
    float time = glutGet(GLUT_ELAPSED_TIME);
    
    // Draw the rotating sun
    glPushMatrix();
       glRotatef(time/100, 0, 1, 0);
       glColor3f(0.8, 0.7, 0);
       glutSolidSphere(10, 8, 8);
    glPopMatrix();
    
    // Draw the earth rotating around the sun
    glPushMatrix();
       glRotatef(time/10, 0, 1, 0); // The earth is rotating on the orbit
       glTranslatef(100, 0, 0);      // The earth is on the orbit
       glRotatef(-time/50, 0, 1, 0); // Rotation of the earth around the axis
       glColor3f(0, 0, 1);
       glutSolidSphere(3, 10, 10);
    glPopMatrix();
    
    // Flush picture
    glutSwapBuffers();
}

// ----------------------------------------------- //
/**
 * Program entry point
 */
int main(int argc, char* argv[]) {

    // Initialize GLUT and create a window
    glutInit(&argc, argv);
    glutInitDisplayMode(GLUT_DOUBLE | GLUT_DEPTH | GLUT_RGB);
    glutInitWindowSize(400, 400);
    glutInitWindowPosition(30,30);
    glutCreateWindow("EIO sessioon - Paikesesysteem");

    // Enable Z-buffer
    glEnable(GL_DEPTH_TEST);
    
    // Enable lighting 
    //   (can you make it so that the Sun is the main source of light?)
    glEnable(GL_LIGHTING);
    glEnable(GL_LIGHT0);
    glEnable(GL_COLOR_MATERIAL);

    // Set up perspective projection
    glMatrixMode(GL_PROJECTION);
        glLoadIdentity();
        gluPerspective(30, 1, 0.5, 10000);
    glMatrixMode(GL_MODELVIEW);
    
    // Register handlers
    glutDisplayFunc(display);
    glutIdleFunc(glutPostRedisplay);
    
    // Run main application loop
    glutMainLoop();
    return 0;
}

